<?php

namespace Content\V1;

use Dever;

class Login
{
    /**
     * @api {get} common 公共参数
     * @apiVersion 1.0.0
     * @apiName common
     * @apiGroup Common
     *
     * @apiDescription 介绍公共参数
     *
     * @apiParam {Number} json 是否返回json格式的数据1为返回2为不返回
     *
     * @apiSuccess {Number}   status  状态，1为有效2为无效
     * @apiSuccess {String}   msg 请求的数据是否成功的提示
     * @apiSuccess {String}   data 如果status为1,data有值
     * @apiSuccess {Object[]}   page 分页信息
     * @apiSuccess {Number}   page.total 分页总数
     * @apiSuccess {Number}   page.current_page 当前页
     * @apiSuccess {Number}   page.total_page 总页数
     * @apiSuccess {Number}   page.next_page 下一页
     * @apiSuccess {Number}   page.prev_page 上一页
     * @apiSuccess {Number}   page.status 是否有下一页数据，0为没有
     *
     * @apiSuccessExample 操作成功
     * {"status":1,"code":1,"msg":"success","data":{"uid":1,"session":"111"}}
     *
     * @apiErrorExample 操作失败
     * {"status":2,"code":1,"msg":"\u9519\u8bef\u7684\u5c0f\u7a0b\u5e8fid"}
     */

    /**
     * @api {get} v1/login.bind 用户登录
     * @apiVersion 1.0.0
     * @apiName login.bind
     * @apiGroup User
     *
     * @apiDescription 用户登录接口
     *
     * @apiParam {Number} appid 小程序id
     * @apiParam {String} code 小程序登录的code
     *
     * @apiSuccess {Number}   uid  用户id
     * @apiSuccess {String}   session 验证用户有效性的session key 请保存在客户端
     *
     * @apiSuccessExample 操作成功
     * {"status":1,"code":1,"msg":"success","data":{"uid":1,"session":"111"}}
     *
     * @apiErrorExample 操作失败
     * {"status":2,"code":1,"msg":"\u9519\u8bef\u7684\u5c0f\u7a0b\u5e8fid"}
     */
    public function bind_api()
    {
        return Dever::load('passport/login.bind');
    }

    /**
     * @api {get} v1/login.update 更新用户信息
     * @apiVersion 1.0.0
     * @apiName login.update
     * @apiGroup User
     *
     * @apiDescription 用户更新信息接口
     *
     * @apiParam {Number} appid 小程序id
     * @apiParam {Number} uid 用户id
     * @apiParam {String} session 验证用户的session
     * @apiParam {String} nickname 用户昵称
     * @apiParam {String} avatarurl 头像
     * @apiParam {String} gender 性别
     * @apiParam {Number} mobile 手机号（目前没有手机号）
     * @apiParam {String} city 城市
     * @apiParam {String} province 省份
     * @apiParam {String} country 国家
     *
     * @apiSuccess {Number}   uid  用户id
     *
     * @apiSuccessExample 操作成功
     * {"status":1,"code":1,"msg":"success","data":1}
     *
     * @apiErrorExample 操作失败
     * {"status":2,"code":1,"msg":"\u9519\u8bef\u7684\u5c0f\u7a0b\u5e8fid"}
     */
    public function update_api()
    {
        return Dever::load('passport/login.update');
    }
}
