<?php

namespace Content\V1;

use Dever;

class Share
{
    public function url_api($link)
    {
        $link = base64_decode($link);
        Dever::location($link);
    }
    /**
     * @api {get} v1/share.submit 提交分享
     * @apiVersion 1.0.0
     * @apiName share.submit
     * @apiGroup Comment
     *
     * @apiDescription 用户提交分享接口
     *
     * @apiParam {Number} appid 小程序id
     * @apiParam {Number} uid 用户id
     * @apiParam {String} session 验证用户的session
     * @apiParam {Number} type 评论的类型：1为资讯2为课程3为会议
     * @apiParam {Number} id 分享的类型id
     * @apiParam {String} content 分享的内容
     *
     * @apiSuccess {Number}   share_uid  用户id
     * @apiSuccess {String}   share_key  分享的session
     * @apiSuccess {Number}   share_id  分享的唯一id
     * @apiSuccess {String}   desc  请将上述几个字段都放到分享的path中：/path/?share_uid=1&share_key=1&share_id=1
     *
     * @apiSuccessExample 操作成功
     * {"status":1,"code":1,"msg":"success","data":{"type":1,"id":1,"uid":1,"key":"11", "share_id":1}}
     *
     * @apiErrorExample 操作失败
     * {"status":2,"code":1,"msg":"\u9519\u8bef\u7684\u5c0f\u7a0b\u5e8fid"}
     */
    public function submit_api()
    {
        return Dever::load('comment/share.submit');
    }

    /**
     * @api {get} v1/share.reflux 分享回流
     * @apiVersion 1.0.0
     * @apiName share.reflux
     * @apiGroup Comment
     *
     * @apiDescription 用户分享回流接口，当path路径中有share_id时，请调用本接口
     *
     * @apiParam {Number} appid 小程序id
     * @apiParam {Number} uid 用户id
     * @apiParam {String} session 验证用户的session
     * @apiParam {Number} share_uid 分享人的用户id
     * @apiParam {Number} share_id 分享的id
     * @apiParam {Number} share_key 分享的session
     *
     * @apiSuccess {Bool}   state  是否成功，无需关注这个接口返回值
     *
     * @apiSuccessExample 操作成功
     * {"status":1,"code":1,"msg":"success","data":true}
     *
     * @apiErrorExample 操作失败
     * {"status":2,"code":1,"msg":"\u9519\u8bef\u7684\u5c0f\u7a0b\u5e8fid"}
     */
    public function reflux_api()
    {
        return Dever::load('comment/share.reflux');
    }
}
